==> org-lsst-ccs-subsystem-fcs-buses-8.2.6-20250916.201808-1-sources.jar: org/lsst/ccs/subsystems/fcs/StatusDataPublishedByAutochangerTwoLatches.java <==

package org.lsst.ccs.subsystems.fcs;

import java.io.Serializable;
import org.lsst.ccs.bus.annotations.DataAttributes;
import org.lsst.ccs.bus.annotations.SkipEncoding;
import org.lsst.ccs.subsystems.fcs.FcsEnumerations.FilterPresenceStatus;
import org.lsst.ccs.subsystems.fcs.FcsEnumerations.LockStatus;

/**
 *
 * @author virieux
 */
public class StatusDataPublishedByAutochangerTwoLatches implements Serializable {
    private static final long serialVersionUID = 8374358651934788527L;

    @DataAttributes(description = "Autochanger latches lockStatus {OPENED; CLOSED; IN_TRAVEL; UNKNOWN; ERROR}", units = "unitless")
    private LockStatus lockStatus;

    @DataAttributes(description = "Autochanger latches filter presence status {ENGAGED; NO_FILTER; UNKNOWN; ERROR}", units = "unitless")
    private FilterPresenceStatus filterPresenceStatus;

    @DataAttributes(description = "Name of filter on autochanger trucks", units = "unitless")
    private String filterName;

    @DataAttributes(description = "ID of filter on autochanger trucks", units = "unitless")
    private int filterID;

    @SkipEncoding
    @DataAttributes(description = "Observatory name of filter on autochanger trucks", units = "unitless")
    private String filterObservatoryName;

    @DataAttributes(description = "Availability of autochanger", units = "unitless")
    private boolean available;

    public StatusDataPublishedByAutochangerTwoLatches() {
    }

    public String getFilterName() {
        return filterName;
    }

    public void setFilterName(String filterName) {
        this.filterName = filterName;
    }

    public int getFilterId() {
        return filterID;
    }

    public void setFilterId(int filterId) {
        this.filterID = filterId;
    }

    public void setFilterObservatoryName(String filterObservatoryName) {
        this.filterObservatoryName = filterObservatoryName;
    }

    public String getFilterObservatoryName() {
        return filterObservatoryName;
    }

    public LockStatus getLockStatus() {
        return lockStatus;
    }

    public void setLockStatus(LockStatus lockStatus) {
        this.lockStatus = lockStatus;
    }

    public FilterPresenceStatus getFilterPresenceStatus() {
        return filterPresenceStatus;
    }

    public void setFilterPresenceStatus(FilterPresenceStatus filterPresenceStatus) {
        this.filterPresenceStatus = filterPresenceStatus;
    }

    public void setAvailable(boolean available) {
        this.available = available;
    }

    public boolean isAvailable() {
       return available;
    }
}

==> org-lsst-ccs-subsystem-fcs-buses-9.0.2-sources.jar: org/lsst/ccs/subsystems/fcs/StatusDataPublishedByAutochangerTwoLatches.java <==

package org.lsst.ccs.subsystems.fcs;

import java.io.Serializable;
import org.lsst.ccs.bus.annotations.DataAttributes;
import org.lsst.ccs.bus.annotations.SkipEncoding;
import org.lsst.ccs.subsystems.fcs.FcsEnumerations.FilterPresenceStatus;
import org.lsst.ccs.subsystems.fcs.FcsEnumerations.LockStatus;

/**
 *
 * @author virieux
 */
public class StatusDataPublishedByAutochangerTwoLatches implements Serializable {
    private static final long serialVersionUID = 8374358651934788527L;

    @DataAttributes(description = "Autochanger latches lockStatus {OPENED; CLOSED; IN_TRAVEL; UNKNOWN; ERROR}", units = "unitless")
    private LockStatus lockStatus;

    @DataAttributes(description = "Autochanger latches filter presence status {ENGAGED; NO_FILTER; UNKNOWN; ERROR}", units = "unitless")
    private FilterPresenceStatus filterPresenceStatus;

    @DataAttributes(description = "Name of filter on autochanger trucks", units = "unitless")
    private String filterName;

    @DataAttributes(description = "ID of filter on autochanger trucks", units = "unitless")
    private int filterID;

    @SkipEncoding
    @DataAttributes(description = "Observatory name of filter on autochanger trucks", units = "unitless")
    private String filterObservatoryName;

    @SkipEncoding
    @DataAttributes(description = "Autochanger delta for Standby position for this filter", units = "micron")
    private int filterDeltaAutochangerStandbyPosition;

    @DataAttributes(description = "Availability of autochanger", units = "unitless")
    private boolean available;

    public StatusDataPublishedByAutochangerTwoLatches() {
    }

    public String getFilterName() {
        return filterName;
    }

    public void setFilterName(String filterName) {
        this.filterName = filterName;
    }

    public int getFilterId() {
        return filterID;
    }

    public void setFilterId(int filterId) {
        this.filterID = filterId;
    }

    public void setFilterObservatoryName(String filterObservatoryName) {
        this.filterObservatoryName = filterObservatoryName;
    }

    public String getFilterObservatoryName() {
        return filterObservatoryName;
    }

    public void setFilterDeltaAutochangerStandbyPosition(int filterDeltaAutochangerStandbyPosition) {
        this.filterDeltaAutochangerStandbyPosition = filterDeltaAutochangerStandbyPosition;
    }

    public int getFilterDeltaAutochangerStandbyPosition() {
        return filterDeltaAutochangerStandbyPosition;
    }

    public LockStatus getLockStatus() {
        return lockStatus;
    }

    public void setLockStatus(LockStatus lockStatus) {
        this.lockStatus = lockStatus;
    }

    public FilterPresenceStatus getFilterPresenceStatus() {
        return filterPresenceStatus;
    }

    public void setFilterPresenceStatus(FilterPresenceStatus filterPresenceStatus) {
        this.filterPresenceStatus = filterPresenceStatus;
    }

    public void setAvailable(boolean available) {
        this.available = available;
    }

    public boolean isAvailable() {
       return available;
    }
}
